<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :isShowHide="true"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="processconfiguration"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import {
  getqualityUnqualifiedConfiguration,
  delqualityUnqualifiedConfiguration
} from '@/api/quality/unqualifiedprocess'
import TableForm from './table-form'
import { mapGetters } from 'vuex'
import { remote } from '@/api/admin/dict'
import ttable from '@/views/common/ztt-table.vue'
export default {
  data() {
    return {
      ajaxFun: getqualityUnqualifiedConfiguration,
      addOrUpdateVisible: false,
      multipleSelection: [],
      typeOptions: [],
      processModeOptions: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'createTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 编号
          {
            minWidth: '140',
            prop: 'workShop',
            label: '车间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          // 产品类型
          {
            minWidth: '120',
            prop: 'type',
            label: '产品类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatType,
            optList: () => {
              return this.typeOptions
            }
          },
          // 处理方式
          {
            minWidth: '200',
            prop: 'processMode',
            label: '处理方式',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatProcessMode,
            optList: () => {
              return this.processModeOptions
            }
          },
          // 发起人
          //   {
          //     minWidth: '200',
          //     prop: 'originator',
          //     label: '发起人',
          //     sort: true,
          //     isTrue: true,
          //     isSearch: true,
          //     searchInfoType: 'text'
          //   },
          // 审核人
          {
            minWidth: '140',
            prop: 'examiner',
            label: '审核人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 处理人
          {
            minWidth: '120',
            prop: 'handler',
            label: '处理人',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      }
    }
  },
  components: {
    TableForm,
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {
    this.getType()
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.processconfiguration.getDataList()
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    formatType(row, column, cellValue) {
      this.typeOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    formatProcessMode(row, column, cellValue) {
      this.processModeOptions.forEach((obj) => {
        if (obj.value === cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    getType() {
      remote('unqualified_handle_type').then((response) => {
        if (response.data.code === 0) {
          this.typeOptions = response.data.data
        }
      })
      remote('unqualified_process_mode').then((response) => {
        if (response.data.code === 0) {
          this.processModeOptions = response.data.data
        }
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除车间为：' + row.workShop, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delqualityUnqualifiedConfiguration(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
